import os
import json
import pytest
from mbti.questions import load_questions

def test_load_questions_quick_zh():
    # 测试加载28题中文版本
    questions = load_questions(version='quick', language='zh')
    assert len(questions) == 28
    assert 'id' in questions[0]
    assert 'question' in questions[0]
    assert 'options' in questions[0]
    assert 'dimension' in questions[0]
    assert questions[0]['id'] == 1
    assert isinstance(questions[0]['question'], dict)
    assert isinstance(questions[0]['options'], dict)
    assert questions[0]['dimension'] in ['EI', 'SN', 'TF', 'JP']

def test_load_questions_quick_en():
    # 测试加载28题英文版本
    questions = load_questions(version='quick', language='en')
    assert len(questions) == 28
    assert 'id' in questions[0]
    assert 'question' in questions[0]
    assert 'options' in questions[0]
    assert 'dimension' in questions[0]
    assert questions[0]['id'] == 1
    assert isinstance(questions[0]['question'], dict)
    assert isinstance(questions[0]['options'], dict)
    assert questions[0]['dimension'] in ['EI', 'SN', 'TF', 'JP']

def test_load_questions_standard_zh():
    # 测试加载93题中文版本
    questions = load_questions(version='standard', language='zh')
    assert len(questions) == 93
    assert 'id' in questions[0]
    assert 'question' in questions[0]
    assert 'options' in questions[0]
    assert 'dimension' in questions[0]
    assert questions[0]['id'] == 1
    assert isinstance(questions[0]['question'], dict)
    assert isinstance(questions[0]['options'], dict)
    assert questions[0]['dimension'] in ['EI', 'SN', 'TF', 'JP']

def test_load_questions_standard_en():
    # 测试加载93题英文版本
    questions = load_questions(version='standard', language='en')
    assert len(questions) == 93
    assert 'id' in questions[0]
    assert 'question' in questions[0]
    assert 'options' in questions[0]
    assert 'dimension' in questions[0]
    assert questions[0]['id'] == 1
    assert isinstance(questions[0]['question'], dict)
    assert isinstance(questions[0]['options'], dict)
    assert questions[0]['dimension'] in ['EI', 'SN', 'TF', 'JP']


import argparse
from mbti.test import run_test
from mbti.results import save_results

def main():
    parser = argparse.ArgumentParser(description='MBTI Personality Test Command Line Program')
    parser.add_argument('--version', action='version', version='%(prog)s 1.0.0')
    parser.add_argument('--short', action='store_true', help='Run the 28-question version')
    parser.add_argument('--long', action='store_true', help='Run the 93-question version')
    parser.add_argument('--save', action='store_true', help='Save results to a CSV file')
    parser.add_argument('--language', choices=['zh', 'en'], default='zh', help='Choose language (zh for Chinese, en for English)')

    args = parser.parse_args()

    # Determine which test to run
    if args.short and args.long:
        print("Error: Cannot specify both --short and --long")
        return
    elif args.short:
        test_version = 'quick'
    elif args.long:
        test_version = 'standard'
    else:
        # Default to short if neither is specified
        test_version = 'quick'

    # Run the test
    results = run_test(test_version, args.language)

    # Save results if requested
    if args.save and results:
        save_results(results, args.language)

if __name__ == "__main__":
    main()


import pytest
import tempfile
import csv
import os
from mbti.results import display_results, save_results
from mbti.calculator import calculate_mbti_type

def test_display_results_zh():
    # 测试中文结果显示
    answers = [
        {'id': 1, 'dimension': 'EI', 'answer': '1'},
        {'id': 2, 'dimension': 'TF', 'answer': '1'},
        {'id': 3, 'dimension': 'JP', 'answer': '1'},
        {'id': 4, 'dimension': 'SN', 'answer': '1'},
    ]
    
    results = calculate_mbti_type(answers)
    
    # 重定向标准输出以捕获打印内容
    import sys
    from io import StringIO
    
    old_stdout = sys.stdout
    sys.stdout = StringIO()
    
    display_results(results, language='zh')
    
    output = sys.stdout.getvalue()
    sys.stdout = old_stdout
    
    assert "你的 MBTI 类型结果:" in output
    assert "总体类型" in output
    assert "维度得分" in output
    assert "外向 (E)" in output
    assert "内向 (I)" in output
    assert "感知 (S)" in output
    assert "直觉 (N)" in output
    assert "思考 (T)" in output
    assert "情感 (F)" in output
    assert "判断 (J)" in output
    assert "感知 (P)" in output

def test_display_results_en():
    # 测试英文结果显示
    answers = [
        {'id': 1, 'dimension': 'EI', 'answer': '1'},
        {'id': 2, 'dimension': 'TF', 'answer': '1'},
        {'id': 3, 'dimension': 'JP', 'answer': '1'},
        {'id': 4, 'dimension': 'SN', 'answer': '1'},
    ]
    
    results = calculate_mbti_type(answers)
    
    # 重定向标准输出以捕获打印内容
    import sys
    from io import StringIO
    
    old_stdout = sys.stdout
    sys.stdout = StringIO()
    
    display_results(results, language='en')
    
    output = sys.stdout.getvalue()
    sys.stdout = old_stdout
    
    assert "Your MBTI Type Results:" in output
    assert "Overall Type" in output
    assert "Dimension Scores" in output
    assert "Extraversion (E)" in output
    assert "Introversion (I)" in output
    assert "Sensing (S)" in output
    assert "Intuition (N)" in output
    assert "Thinking (T)" in output
    assert "Feeling (F)" in output
    assert "Judging (J)" in output
    assert "Perceiving (P)" in output

def test_save_results():
    # 测试保存结果到CSV文件
    answers = [
        {'id': 1, 'dimension': 'EI', 'answer': '1'},
        {'id': 2, 'dimension': 'TF', 'answer': '1'},
        {'id': 3, 'dimension': 'JP', 'answer': '1'},
        {'id': 4, 'dimension': 'SN', 'answer': '1'},
    ]
    
    results = calculate_mbti_type(answers)
    
    # 创建临时目录保存结果
    with tempfile.TemporaryDirectory() as temp_dir:
        # 保存结果
        save_results(results, language='zh')
        
        # 检查文件是否创建
        assert os.path.exists(os.path.join(temp_dir, 'results'))
        
        # 检查CSV文件内容
        csv_files = [f for f in os.listdir(os.path.join(temp_dir, 'results')) if f.endswith('.csv')]
        assert len(csv_files) == 1
        
        csv_file = csv_files[0]
        csv_path = os.path.join(temp_dir, 'results', csv_file)
        
        with open(csv_path, 'r', encoding='utf-8') as f:
            reader = csv.DictReader(f)
            rows = list(reader)
            assert len(rows) == 1
            assert rows[0]['Dimension'] == 'Overall'
            assert rows[0]['Type'] == 'ESTJ'
            assert int(rows[0]['Score_E']) == 4
            assert int(rows[0]['Score_I']) == 0
            assert int(rows[0]['Score_S']) == 4
            assert int(rows[0]['Score_N']) == 0
            assert int(rows[0]['Score_T']) == 4
            assert int(rows[0]['Score_F']) == 0
            assert int(rows[0]['Score_J']) == 4
            assert int(rows[0]['Score_P']) == 0


def calculate_mbti_type(answers):
    # Initialize scores for each dimension
    scores = {
        'E': 0,
        'I': 0,
        'S': 0,
        'N': 0,
        'T': 0,
        'F': 0,
        'J': 0,
        'P': 0
    }

    # Score each answer
    for answer in answers:
        dimension = answer['dimension']
        choice = int(answer['answer'])

        # For each dimension, answer 1 or 2 affects the score
        if dimension == 'EI':
            if choice == 1:
                scores['E'] += 1
            else:
                scores['I'] += 1
        elif dimension == 'SN':
            if choice == 1:
                scores['S'] += 1
            else:
                scores['N'] += 1
        elif dimension == 'TF':
            if choice == 1:
                scores['T'] += 1
            else:
                scores['F'] += 1
        elif dimension == 'JP':
            if choice == 1:
                scores['J'] += 1
            else:
                scores['P'] += 1

    # Determine the dominant type for each dimension
    mbti_type = ''
    mbti_type += 'E' if scores['E'] > scores['I'] else 'I'
    mbti_type += 'S' if scores['S'] > scores['N'] else 'N'
    mbti_type += 'T' if scores['T'] > scores['F'] else 'F'
    mbti_type += 'J' if scores['J'] > scores['P'] else 'P'

    return {
        'scores': scores,
        'type': mbti_type
    }


import json
import os

def load_questions(version='quick', language='zh'):
    # Determine the path to the questions file
    current_dir = os.path.dirname(os.path.abspath(__file__))
    data_dir = os.path.join(current_dir, 'data')
    if version == 'quick':
        questions_file = os.path.join(data_dir, 'questions_quick.json')
    else:
        questions_file = os.path.join(data_dir, 'questions_standard.json')

    # Load questions from file
    with open(questions_file, 'r', encoding='utf-8') as f:
        questions_data = json.load(f)

    return questions_data['MBTI_questions']


from mbti.questions import load_questions
from mbti.calculator import calculate_mbti_type
from mbti.results import display_results

def run_test(version='quick', language='zh'):
    questions = load_questions(version, language)
    answers = []

    print(f"\nStarting the MBTI test ({version} version) in {language} language")
    print(f"This test contains {len(questions)} questions.")
    input("Press Enter to start...")

    for question in questions:
        print(f"\nQuestion {question['id']}: {question['question'][language]}")
        print("Options:")
        for i, option in enumerate(question['options'][language]):
            print(f"{i+1}. {option}")
        
        while True:
            try:
                answer = input("Your answer (1 or 2): ")
                if answer in ['1', '2']:
                    answers.append({
                        'id': question['id'],
                        'dimension': question['dimension'],
                        'answer': answer
                    })
                    break
                else:
                    print("Invalid input. Please enter 1 or 2.")
            except KeyboardInterrupt:
                print("\nTest interrupted. Exiting...")
                return None

    results = calculate_mbti_type(answers)
    display_results(results, language)

    return results


from setuptools import setup, find_packages

setup(
    name='mbti-test',
    version='0.1.0',
    package_dir={'': 'src'},
    packages=find_packages(where='src'),
    install_requires=[
        # 添加项目依赖项
    ],
    entry_points={
        'console_scripts': [
            'mbti-test=mbti.entry_point:main'
        ]
    },
    package_data={
        'mbti': [
            'data/questions_quick.json',
            'data/questions_standard.json'
        ]
    },
    include_package_data=True,
    author='luhuadong',
    author_email='luhuadong@163.com',
    description='A command line application for taking the MBTI personality test',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/luhuadong/mbti-test',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)


import csv
import os
from datetime import datetime

def display_results(results, language='zh'):
    messages = {
        'zh': {
            'type': '你的 MBTI 类型结果:',
            'overall': '总体类型',
            'scores': '维度得分',
            'e': '外向 (E)',
            'i': '内向 (I)',
            's': '感知 (S)',
            'n': '直觉 (N)',
            't': '思考 (T)',
            'f': '情感 (F)',
            'j': '判断 (J)',
            'p': '感知 (P)'
        },
        'en': {
            'type': 'Your MBTI Type Results:',
            'overall': 'Overall Type',
            'scores': 'Dimension Scores',
            'e': 'Extraversion (E)',
            'i': 'Introversion (I)',
            's': 'Sensing (S)',
            'n': 'Intuition (N)',
            't': 'Thinking (T)',
            'f': 'Feeling (F)',
            'j': 'Judging (J)',
            'p': 'Perceiving (P)'
        }
    }

    print(f"\n{messages[language]['type']}")
    print(f"{messages[language]['overall']}: {results['type']}")
    print(f"\n{messages[language]['scores']}:")
    print(f"{messages[language]['e']} vs {messages[language]['i']}: {results['scores']['E']} - {results['scores']['I']}")
    print(f"{messages[language]['s']} vs {messages[language]['n']}: {results['scores']['S']} - {results['scores']['N']}")
    print(f"{messages[language]['t']} vs {messages[language]['f']}: {results['scores']['T']} - {results['scores']['F']}")
    print(f"{messages[language]['j']} vs {messages[language]['p']}: {results['scores']['J']} - {results['scores']['P']}")

def save_results(results, language='zh'):
    # Create results directory if it doesn't exist
    current_dir = os.getcwd()
    results_dir = os.path.join(current_dir, 'results')
    os.makedirs(results_dir, exist_ok=True)

    # Generate filename with timestamp
    timestamp = datetime.now().strftime("%Y%m%d%H%M%S")
    filename = os.path.join(results_dir, f"mbti_results_{timestamp}.csv")

    # Write results to CSV file
    with open(filename, 'w', newline='', encoding='utf-8') as csvfile:
        fieldnames = ['Dimension', 'Score_E', 'Score_I', 'Score_S', 'Score_N', 'Score_T', 'Score_F', 'Score_J', 'Score_P', 'Type']
        writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
        writer.writeheader()
        writer.writerow({
            'Dimension': 'Overall',
            'Score_E': results['scores']['E'],
            'Score_I': results['scores']['I'],
            'Score_S': results['scores']['S'],
            'Score_N': results['scores']['N'],
            'Score_T': results['scores']['T'],
            'Score_F': results['scores']['F'],
            'Score_J': results['scores']['J'],
            'Score_P': results['scores']['P'],
            'Type': results['type']
        })

    print(f"\nResults saved to {filename}")


import pytest
from mbti.calculator import calculate_mbti_type

def test_calculate_mbti_type():
    # 测试计算MBTI类型
    answers = [
        {'id': 1, 'dimension': 'EI', 'answer': '1'},
        {'id': 2, 'dimension': 'TF', 'answer': '1'},
        {'id': 3, 'dimension': 'JP', 'answer': '1'},
        {'id': 4, 'dimension': 'SN', 'answer': '1'},
        {'id': 5, 'dimension': 'JP', 'answer': '1'},
        {'id': 6, 'dimension': 'TF', 'answer': '1'},
        {'id': 7, 'dimension': 'SN', 'answer': '1'},
        {'id': 8, 'dimension': 'EI', 'answer': '1'},
        {'id': 9, 'dimension': 'TF', 'answer': '1'},
        {'id': 10, 'dimension': 'JP', 'answer': '1'},
        {'id': 11, 'dimension': 'SN', 'answer': '1'},
        {'id': 12, 'dimension': 'EI', 'answer': '1'},
        {'id': 13, 'dimension': 'TF', 'answer': '1'},
        {'id': 14, 'dimension': 'JP', 'answer': '1'},
        {'id': 15, 'dimension': 'SN', 'answer': '1'},
    ]
    
    results = calculate_mbti_type(answers)
    
    assert results['type'] == 'ESTJ'
    assert results['scores']['E'] == 7
    assert results['scores']['I'] == 0
    assert results['scores']['S'] == 7
    assert results['scores']['N'] == 0
    assert results['scores']['T'] == 7
    assert results['scores']['F'] == 0
    assert results['scores']['J'] == 7
    assert results['scores']['P'] == 0

def test_calculate_mbti_type_mixed():
    # 测试混合回答的MBTI类型计算
    answers = [
        {'id': 1, 'dimension': 'EI', 'answer': '1'},
        {'id': 2, 'dimension': 'TF', 'answer': '1'},
        {'id': 3, 'dimension': 'JP', 'answer': '1'},
        {'id': 4, 'dimension': 'SN', 'answer': '1'},
        {'id': 5, 'dimension': 'JP', 'answer': '2'},
        {'id': 6, 'dimension': 'TF', 'answer': '2'},
        {'id': 7, 'dimension': 'SN', 'answer': '2'},
        {'id': 8, 'dimension': 'EI', 'answer': '2'},
        {'id': 9, 'dimension': 'TF', 'answer': '1'},
        {'id': 10, 'dimension': 'JP', 'answer': '2'},
        {'id': 11, 'dimension': 'SN', 'answer': '1'},
        {'id': 12, 'dimension': 'EI', 'answer': '1'},
        {'id': 13, 'dimension': 'TF', 'answer': '2'},
        {'id': 14, 'dimension': 'JP', 'answer': '1'},
        {'id': 15, 'dimension': 'SN', 'answer': '2'},
    ]
    
    results = calculate_mbti_type(answers)
    
    assert results['type'] == 'ENFP'
    assert results['scores']['E'] == 3
    assert results['scores']['I'] == 2
    assert results['scores']['S'] == 2
    assert results['scores']['N'] == 3
    assert results['scores']['T'] == 2
    assert results['scores']['F'] == 3
    assert results['scores']['J'] == 2
    assert results['scores']['P'] == 3